==> dif-database-repository-2.3.11-7-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/ConfigServerSet.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;

/**
 * ConfigServerSet
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class ConfigServerSet extends AbstractBeanRelationsAttributes implements java.io.Serializable {

    /** ConfigServerSet attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** serverUid column */
        public static final String SERVERUID = "serverUid";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("serverUid");

            return list;
        }
    }

	/**
 	 * The Class Relations.
 	 */
	 public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations {

        /**
         * Instantiates a new relations.
         *
         * @param currentPath
         *            the current path
         */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * configSet relation.
         *
         * @return the configSet bean relations attributes.
         */
        public ConfigSet.Relations configSet()
        {
			ConfigSet c = new ConfigSet();
            return c.new Relations(this.buildPath("configSet"));
        }
        
		/**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
		/**
         * the SERVERUID path.
         *
         * @return the path
         */
        public String SERVERUID()
        {
            return buildPath(Fields.SERVERUID);
        }
    }
	
	/** The dummy obj. */
    private static ConfigServerSet dummyObj = new ConfigServerSet();

	/**
     * Get ConfigServerSet Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    @Override
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("configSet".equalsIgnoreCase(attributeName))
            return configSet;
        if ("serverUid".equalsIgnoreCase(attributeName))
            return serverUid;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("configSet".equalsIgnoreCase(attributeName))
            configSet = (ConfigSet)attributeValue;
        if ("serverUid".equalsIgnoreCase(attributeName))
            serverUid = (String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** configSet private attribute */
    private ConfigSet configSet;

    /** serverUid private attribute */
    private String serverUid;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public ConfigServerSet() {
    }


    /**
     * full constructor
	 *
     * @param configSet
     * @param serverUid
     */
    public ConfigServerSet(ConfigSet configSet, String serverUid) {
        this.configSet = configSet;
        this.serverUid = serverUid;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return ConfigServerSet modified instance
     */
    public ConfigServerSet setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * configSet getter method
     *
     * @return configSet method
     */
    public ConfigSet getConfigSet() {
        return this.configSet;
    }
    
    /**       
     * configSet setter method
     *
     * @param configSet
     *
     * @return ConfigServerSet modified instance
     */
    public ConfigServerSet setConfigSet(ConfigSet configSet) {
        this.configSet = configSet;
        
        return this;
    }
    /**       
     * serverUid getter method
     *
     * @return serverUid method
     */
    public String getServerUid() {
        return this.serverUid;
    }
    
    /**       
     * serverUid setter method
     *
     * @param serverUid
     *
     * @return ConfigServerSet modified instance
     */
    public ConfigServerSet setServerUid(String serverUid) {
        this.serverUid = serverUid;
        
        return this;
    }

    /**
     * Creates a String representation of the ConfigServerSet object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("serverUid").append("='").append(getServerUid()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the ConfigServerSet object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(ConfigServerSet other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("serverUid".equalsIgnoreCase(attributeName))
        	this.serverUid = attributeValue;

    }


}

==> dif-database-repository-2.6.1-8-20200421.173538-1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/ConfigServerSet.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;

/**
 * ConfigServerSet
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class ConfigServerSet extends AbstractBeanRelationsAttributes implements java.io.Serializable {

    /** ConfigServerSet attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** serverUid column */
        public static final String SERVERUID = "serverUid";
        /** isDefault column */
        public static final String ISDEFAULT = "isDefault";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("serverUid");
            list.add("isDefault");

            return list;
        }
    }

	/**
 	 * The Class Relations.
 	 */
	 public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations {

        /**
         * Instantiates a new relations.
         *
         * @param currentPath
         *            the current path
         */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * configSet relation.
         *
         * @return the configSet bean relations attributes.
         */
        public ConfigSet.Relations configSet()
        {
			ConfigSet c = new ConfigSet();
            return c.new Relations(this.buildPath("configSet"));
        }
        
		/**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
		/**
         * the SERVERUID path.
         *
         * @return the path
         */
        public String SERVERUID()
        {
            return buildPath(Fields.SERVERUID);
        }
		/**
         * the ISDEFAULT path.
         *
         * @return the path
         */
        public String ISDEFAULT()
        {
            return buildPath(Fields.ISDEFAULT);
        }
    }
	
	/** The dummy obj. */
    private static ConfigServerSet dummyObj = new ConfigServerSet();

	/**
     * Get ConfigServerSet Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    @Override
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("configSet".equalsIgnoreCase(attributeName))
            return configSet;
        if ("serverUid".equalsIgnoreCase(attributeName))
            return serverUid;
        if ("isDefault".equalsIgnoreCase(attributeName))
            return isDefault;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("configSet".equalsIgnoreCase(attributeName))
            configSet = (ConfigSet)attributeValue;
        if ("serverUid".equalsIgnoreCase(attributeName))
            serverUid = (String)attributeValue;
        if ("isDefault".equalsIgnoreCase(attributeName))
            isDefault = (Boolean)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** configSet private attribute */
    private ConfigSet configSet;

    /** serverUid private attribute */
    private String serverUid;

    /** isDefault private attribute */
    private boolean isDefault;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public ConfigServerSet() {
    }


    /**
     * full constructor
	 *
     * @param configSet
     * @param serverUid
     * @param isDefault
     */
    public ConfigServerSet(ConfigSet configSet, String serverUid, boolean isDefault) {
        this.configSet = configSet;
        this.serverUid = serverUid;
        this.isDefault = isDefault;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return ConfigServerSet modified instance
     */
    public ConfigServerSet setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * configSet getter method
     *
     * @return configSet method
     */
    public ConfigSet getConfigSet() {
        return this.configSet;
    }
    
    /**       
     * configSet setter method
     *
     * @param configSet
     *
     * @return ConfigServerSet modified instance
     */
    public ConfigServerSet setConfigSet(ConfigSet configSet) {
        this.configSet = configSet;
        
        return this;
    }
    /**       
     * serverUid getter method
     *
     * @return serverUid method
     */
    public String getServerUid() {
        return this.serverUid;
    }
    
    /**       
     * serverUid setter method
     *
     * @param serverUid
     *
     * @return ConfigServerSet modified instance
     */
    public ConfigServerSet setServerUid(String serverUid) {
        this.serverUid = serverUid;
        
        return this;
    }
    /**       
     * isDefault getter method
     *
     * @return isDefault method
     */
    public boolean isIsDefault() {
        return this.isDefault;
    }
    
    /**       
     * isDefault setter method
     *
     * @param isDefault
     *
     * @return ConfigServerSet modified instance
     */
    public ConfigServerSet setIsDefault(boolean isDefault) {
        this.isDefault = isDefault;
        
        return this;
    }

    /**
     * Creates a String representation of the ConfigServerSet object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("serverUid").append("='").append(getServerUid()).append("' ");			
        buffer.append("isDefault").append("='").append(isIsDefault()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the ConfigServerSet object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(ConfigServerSet other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("serverUid".equalsIgnoreCase(attributeName))
        	this.serverUid = attributeValue;

        if ("isDefault".equalsIgnoreCase(attributeName))
            this.isDefault = Boolean.valueOf(attributeValue);

    }


}
